==> calf_0.90.1.orig.tar.gz: calf-0.90.1/README.md <==
Calf Studio gear
================

Calf Studio Gear is an audio plug-in pack for LV2 and JACK environments
under LINUX operating systems. The suite contains lots of effects
(delay, modulation, signal processing, filters, equalizers, dynamics,
distortion and mastering effects), instruments (SF2 player, organ
simulator and a monophonic synthesizer) and tools (analyzer, mono/stereo
tools, crossovers). Calf Studio Gear aims for a professional audience.

Please visit the website below for further information,
screenshots and installation instructions.

http://calf-studio-gear.org

Features
--------

- Instruments and tone generators (Organ, Monosynth, Wavetable, Fluidsynth)
- Modulation effects (Multi Chorus, Phaser, Flanger, Rotary, Pulsator, Ring Modulator)
- Delay effects (Reverb, Vintage Delay,Compensation Delay Line, Reverse Delay)
- Dynamic processors (Compressor, Sidechain Compressor, Multiband Compressor, Mono Compressor, Deesser, Gate, Sidechain Gate, Multiband Gate, Limiter, Multiband Limiter, Sidechain Limiter, Transient Designer)
- Filters and equalizers (Filter, Filterclavier, Envelope Filter, Equalizer 5 Band, Equalizer 8 Band, Equalizer 12 Band, Equalizer 30 Band, Vocoder, Emphasis)
- Distortion and enhancement (Saturator, Exciter, Bass Enhancer, Tape Simulator, Vinyl, Crusher)
- Tools (Mono Input, Stereo Tools, Haas Stereo Enhancer, Multi Spread, Analyzer, X-Over 2 Band, X-Over 3 Band, X-Over 4 Band)

Usage
-----

Once installed there are a couple of manuals available.

- "man calf" displays some general instructions
- "man calfjackhost" gives some hints on how to use the calf rack application
- /usr/[local]/share/doc/calf (depending on your installation path) contains a HTML manual on how to use the plug-ins user interface
- The plug-in manuals can also be accessed via the GUI menus.

==> calf_0.90.6.orig.tar.gz: calf-0.90.6/README.md <==
# Calf Studio gear

[![Build status](https://github.com/calf-studio-gear/calf/actions/workflows/build.yml/badge.svg)](https://github.com/calf-studio-gear/calf/actions/workflows/build.yml)

Calf Studio Gear is an audio plug-in pack for LV2 and JACK environments
under LINUX operating systems. The suite contains lots of effects
(delay, modulation, signal processing, filters, equalizers, dynamics,
distortion and mastering effects), instruments (SF2 player, organ
simulator and a monophonic synthesizer) and tools (analyzer, mono/stereo
tools, crossovers). Calf Studio Gear aims for a professional audience.

Please visit the website below for further information,
screenshots and installation instructions.

http://calf-studio-gear.org

## Features

- Instruments and tone generators (Organ, Monosynth, Wavetable, Fluidsynth)
- Modulation effects (Multi Chorus, Phaser, Flanger, Rotary, Pulsator, Ring Modulator)
- Delay effects (Reverb, Vintage Delay,Compensation Delay Line, Reverse Delay)
- Dynamic processors (Compressor, Sidechain Compressor, Multiband Compressor, Mono Compressor, Deesser, Gate, Sidechain Gate, Multiband Gate, Limiter, Multiband Limiter, Sidechain Limiter, Transient Designer)
- Filters and equalizers (Filter, Filterclavier, Envelope Filter, Equalizer 5 Band, Equalizer 8 Band, Equalizer 12 Band, Equalizer 30 Band, Vocoder, Emphasis)
- Distortion and enhancement (Saturator, Exciter, Bass Enhancer, Tape Simulator, Vinyl, Crusher)
- Tools (Mono Input, Stereo Tools, Haas Stereo Enhancer, Multi Spread, Analyzer, X-Over 2 Band, X-Over 3 Band, X-Over 4 Band)

## Usage

Once installed there are a couple of manuals available.

- "man calf" displays some general instructions
- "man calfjackhost" gives some hints on how to use the calf rack application
- /usr/[local]/share/doc/calf (depending on your installation path) contains a HTML manual on how to use the plug-ins user interface
- The plug-in manuals can also be accessed via the GUI menus.

## Installation

CMake: INSTALL  (recommended)
Automake: INSTALL-AUTOMAKE  (deprecated!)

Note that CMake only build is checked by CI, and only CMake will work for native Windows compiling.
